==> dhall-yaml-1.2.12-31-x86_64.pkg.tar.zst: usr/share/haskell/register/dhall-yaml.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 dhall-yaml
version:              1.2.12
visibility:           public
id:                   dhall-yaml-1.2.12-oiUTOMiYqMBriSLR1Qy0o
key:                  dhall-yaml-1.2.12-oiUTOMiYqMBriSLR1Qy0o
license:              GPL-3.0-only
copyright:            2019 Gabriella Gonzalez
maintainer:           GenuineGabriella@gmail.com
author:               Gabriella Gonzalez
synopsis:             Convert between Dhall and YAML
description:
    Use this package if you want to convert between Dhall expressions and YAML.
    You can use this package as a library or an executable:

    * See the "Dhall.Yaml" module if you want to use this package as a library

    * Use the @dhall-to-yaml-ng@ program from this package if you want an executable

category:             Compiler
abi:                  1f6f5a6cf3c3659a663adf041c09d633
exposed:              True
exposed-modules:      Dhall.Yaml Dhall.YamlToDhall
import-dirs:          /usr/lib/ghc-9.4.8/site-local/dhall-yaml-1.2.12
library-dirs:         /usr/lib/ghc-9.4.8/site-local/dhall-yaml-1.2.12
library-dirs-static:  /usr/lib/ghc-9.4.8/site-local/dhall-yaml-1.2.12
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/dhall-yaml
hs-libraries:         HSdhall-yaml-1.2.12-oiUTOMiYqMBriSLR1Qy0o
depends:
    HsYAML-0.2.1.3-29vEQ31y4k8Aj5xE3kbzDk
    HsYAML-aeson-0.2.0.1-8zg0S1bwqNa3TuNiyTHkO7
    aeson-2.1.2.1-17AWhWkbfJE926UMi0wPlA base-4.17.2.1
    bytestring-0.11.5.3 dhall-1.42.1-1koOAKfizOi5i52fCyuZI9
    dhall-json-1.7.12-7GPqCoPqxDP11ERVq96tRD
    optparse-applicative-0.17.1.0-4tPjpOfYmOi9nj8To0UB1j text-2.0.2
    vector-0.13.1.0-Dc65CzydytHE52tdajtbOv

haddock-interfaces:   /usr/share/doc/dhall-yaml/html/dhall-yaml.haddock
haddock-html:         /usr/share/doc/dhall-yaml/html
' | '/usr/bin/ghc-pkg-9.4.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> dhall-yaml-1.2.12-32-x86_64.pkg.tar.zst: usr/share/haskell/register/dhall-yaml.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 dhall-yaml
version:              1.2.12
visibility:           public
id:                   dhall-yaml-1.2.12-EFRf1PDhLrnL9JmIWvtnaq
key:                  dhall-yaml-1.2.12-EFRf1PDhLrnL9JmIWvtnaq
license:              GPL-3.0-only
copyright:            2019 Gabriella Gonzalez
maintainer:           GenuineGabriella@gmail.com
author:               Gabriella Gonzalez
synopsis:             Convert between Dhall and YAML
description:
    Use this package if you want to convert between Dhall expressions and YAML.
    You can use this package as a library or an executable:

    * See the "Dhall.Yaml" module if you want to use this package as a library

    * Use the @dhall-to-yaml-ng@ program from this package if you want an executable

category:             Compiler
abi:                  be61778488c4b620a3277567a7b72d21
exposed:              True
exposed-modules:      Dhall.Yaml Dhall.YamlToDhall
import-dirs:          /usr/lib/ghc-9.4.8/site-local/dhall-yaml-1.2.12
library-dirs:         /usr/lib/ghc-9.4.8/site-local/dhall-yaml-1.2.12
library-dirs-static:  /usr/lib/ghc-9.4.8/site-local/dhall-yaml-1.2.12
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/dhall-yaml
hs-libraries:         HSdhall-yaml-1.2.12-EFRf1PDhLrnL9JmIWvtnaq
depends:
    HsYAML-0.2.1.3-29vEQ31y4k8Aj5xE3kbzDk
    HsYAML-aeson-0.2.0.1-8zg0S1bwqNa3TuNiyTHkO7
    aeson-2.1.2.1-17AWhWkbfJE926UMi0wPlA base-4.17.2.1
    bytestring-0.11.5.3 dhall-1.42.1-CQMf3hjKFfN4o6t4pz98MS
    dhall-json-1.7.12-5R36l5z2gdbEkR3jU7OJCS
    optparse-applicative-0.17.1.0-4tPjpOfYmOi9nj8To0UB1j text-2.0.2
    vector-0.13.1.0-Dc65CzydytHE52tdajtbOv

haddock-interfaces:   /usr/share/doc/dhall-yaml/html/dhall-yaml.haddock
haddock-html:         /usr/share/doc/dhall-yaml/html
' | '/usr/bin/ghc-pkg-9.4.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
